# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypeAlias

__all__ = ["Visibility"]

Visibility: TypeAlias = Literal["visible", "hidden", "archived", "quick_link"]
