# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["Currency"]

Currency: TypeAlias = Literal[
    "usd",
    "sgd",
    "inr",
    "aud",
    "brl",
    "cad",
    "dkk",
    "eur",
    "nok",
    "gbp",
    "sek",
    "chf",
    "hkd",
    "huf",
    "jpy",
    "mxn",
    "myr",
    "pln",
    "czk",
    "nzd",
    "aed",
    "eth",
    "ape",
    "cop",
    "ron",
    "thb",
    "bgn",
    "idr",
    "dop",
    "php",
    "try",
    "krw",
    "twd",
    "vnd",
    "pkr",
    "clp",
    "uyu",
    "ars",
    "zar",
    "dzd",
    "tnd",
    "mad",
    "kes",
    "kwd",
    "jod",
    "all",
    "xcd",
    "amd",
    "bsd",
    "bhd",
    "bob",
    "bam",
    "khr",
    "crc",
    "xof",
    "egp",
    "etb",
    "gmd",
    "ghs",
    "gtq",
    "gyd",
    "ils",
    "jmd",
    "mop",
    "mga",
    "mur",
    "mdl",
    "mnt",
    "nad",
    "ngn",
    "mkd",
    "omr",
    "pyg",
    "pen",
    "qar",
    "rwf",
    "sar",
    "rsd",
    "lkr",
    "tzs",
    "ttd",
    "uzs",
    "rub",
    "btc",
]
