# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypeAlias

__all__ = ["AppStatuses"]

AppStatuses: TypeAlias = Literal["live", "unlisted", "hidden"]
