# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypeAlias

__all__ = ["IndustryTypes"]

IndustryTypes: TypeAlias = Literal[
    "trading",
    "sports_betting",
    "reselling",
    "fitness",
    "amazon_fba",
    "real_estate",
    "kindle_book_publishing",
    "dating",
    "agencies",
    "health_and_wellness",
    "social_media",
    "sales",
    "business",
    "ecommerce",
    "video_games",
    "home_services",
    "ai",
    "public_speaking",
    "personal_finance",
    "careers",
    "travel",
    "clipping",
    "spirituality",
    "vas",
    "personal_development",
    "software",
    "other",
    "marketing_agency",
    "sales_agency",
    "ai_agency",
    "design_agency",
    "coaching_agency",
    "development_agency",
    "recruiting_agency",
    "customer_support_agency",
    "clipping_agency",
    "clothing",
    "supplements",
    "beauty_and_personal_care",
    "fitness_gear",
    "accessories",
    "home_goods",
    "electronics_and_gadgets",
    "food_and_beverages",
    "gym",
    "restaurant",
    "retail_store",
    "coffee_shop",
    "salon_spa",
    "medical_dentist_office",
    "hotel_lodging",
    "auto_repair_shop",
    "masterminds",
    "webinars",
    "bootcamps",
    "convention",
    "concerts",
    "meetups",
    "parties",
]
