# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["ShipmentCarrier"]

ShipmentCarrier: TypeAlias = Literal[
    "accurate",
    "amazon_mws",
    "amazon_shipping",
    "apc",
    "asendia_usa",
    "australia_post",
    "axlehire_v3",
    "better_trucks",
    "canada_post",
    "canpar",
    "columbus_last_mile",
    "chronopost",
    "cloud_sort",
    "courier_express",
    "couriers_please",
    "cs_logistics",
    "dai_post",
    "deutsche_post_uk",
    "deutsche_post",
    "dhl_ecommerce_asia",
    "dhl_ecs",
    "dhl_express",
    "dhl_paket",
    "door_dash",
    "dpd_nl",
    "dpd_uk",
    "dpd",
    "epost_global",
    "estafeta",
    "evri",
    "fastway",
    "fedex_cross_border",
    "fedex_default",
    "fedex_mailview",
    "fedex_smartpost",
    "fedex",
    "first_choice",
    "first_mile",
    "flexport",
    "gio",
    "gio_express",
    "gso",
    "hailify",
    "henry",
    "interlink_express",
    "jet",
    "kuroneko_yamato",
    "la_post",
    "lasership_v2",
    "loomis_express",
    "lso",
    "ontrac",
    "optima",
    "osm_worldwide",
    "parcelforce",
    "parcll",
    "passport_global",
    "post_nl",
    "purolator",
    "quick",
    "royal_mail",
    "omni_parcel",
    "sendle",
    "sf_express",
    "smart_kargo",
    "sonic",
    "spee_dee",
    "swyft",
    "tforce",
    "uds",
    "ups_iparcel",
    "ups_mail_innovations",
    "ups",
    "usps",
    "veho",
    "yanwen",
]
