# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, TypeAlias

__all__ = ["BusinessTypes"]

BusinessTypes: TypeAlias = Literal[
    "education_program",
    "coaching",
    "software",
    "paid_group",
    "newsletter",
    "agency",
    "physical_products",
    "brick_and_mortar",
    "events",
    "coaching_and_courses",
    "other",
    "saas",
    "course",
    "community",
]
