# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["CustomCta"]

CustomCta: TypeAlias = Literal[
    "get_access",
    "join",
    "order_now",
    "shop_now",
    "call_now",
    "donate_now",
    "contact_us",
    "sign_up",
    "subscribe",
    "purchase",
    "get_offer",
    "apply_now",
    "complete_order",
]
